SoarScore
Author: Anne Hoekstra
Description: Track latest tasks for CVL - Semana de Voo à Vela do Alentejo 2020 - Portugal

#### CVL - Semana de Voo à Vela do Alentejo 2020 - Portugal

June 27, 2020 – July 5, 2020
Amendoeira (Portugal)
Total competition distance: 241 km

Silver Day4 No task
Bronze Day4 No task
Gold Day4 No task

Competition results on soaringspot.com

Silver Day4 No task
Silver Day3 Task1 - 84km Race
Silver Day2 No task
Silver Day1 No task

Bronze Day4 No task
Bronze Day3 Task1 - 73km Race
Bronze Day2 No task
Bronze Day1 No task

Gold Day4 No task
Gold Day3 Task1 - 84km Race
Gold Day2 No task
Gold Day1 No task

Competition results on soaringspot.com

> Competion Facebook Stream